==> root-debug-6.36.04-5-x86_64.pkg.tar.zst: usr/src/debug/root/build-cuda/tree/ntupleutil/G__ROOTNTupleUtil.cxx <==
// Do NOT change. Changes will be lost next time file is generated

#define R__DICTIONARY_FILENAME G__ROOTNTupleUtil
#define R__NO_DEPRECATION

/*******************************************************************/
#include <stddef.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <assert.h>
#define G__DICTIONARY
#include "ROOT/RConfig.hxx"
#include "TClass.h"
#include "TDictAttributeMap.h"
#include "TInterpreter.h"
#include "TROOT.h"
#include "TBuffer.h"
#include "TMemberInspector.h"
#include "TInterpreter.h"
#include "TVirtualMutex.h"
#include "TError.h"

#ifndef G__ROOT
#define G__ROOT
#endif

#include "RtypesImp.h"
#include "TIsAProxy.h"
#include "TFileMergeInfo.h"
#include <algorithm>
#include "TCollectionProxyInfo.h"
/*******************************************************************/

#include "TDataMember.h"

// Header files passed as explicit arguments
#include "ROOT/RNTupleImporter.hxx"
#include "ROOT/RNTupleExporter.hxx"
#include "ROOT/RNTupleInspector.hxx"

// Header files passed via #pragma extra_include

// The generated code does not explicitly qualify STL entities
namespace std {} using namespace std;

namespace ROOT {
   // Registration Schema evolution read functions
   int RecordReadRules_libROOTNTupleUtil() {
      return 0;
   }
   static int _R__UNIQUE_DICT_(ReadRules_libROOTNTupleUtil) = RecordReadRules_libROOTNTupleUtil();R__UseDummy(_R__UNIQUE_DICT_(ReadRules_libROOTNTupleUtil));
} // namespace ROOT
namespace {
  void TriggerDictionaryInitialization_libROOTNTupleUtil_Impl() {
    static const char* headers[] = {
"ROOT/RNTupleImporter.hxx",
"ROOT/RNTupleExporter.hxx",
"ROOT/RNTupleInspector.hxx",
nullptr
    };
    static const char* includePaths[] = {
"/build/root/src/build-cuda/include",
"/usr/include",
"/usr/include",
"/build/root/src/build-cuda/include/",
nullptr
    };
    static const char* fwdDeclCode = R"DICTFWDDCLS(
#line 1 "libROOTNTupleUtil dictionary forward declarations' payload"
#pragma clang diagnostic ignored "-Wkeyword-compat"
#pragma clang diagnostic ignored "-Wignored-attributes"
#pragma clang diagnostic ignored "-Wreturn-type-c-linkage"
extern int __Cling_AutoLoading_Map;
)DICTFWDDCLS";
    static const char* payloadCode = R"DICTPAYLOAD(
#line 1 "libROOTNTupleUtil dictionary payload"

#ifndef ROOT_SUPPORT_CLAD
  #define ROOT_SUPPORT_CLAD 1
#endif

#define _BACKWARD_BACKWARD_WARNING_H
// Inline headers
#include "ROOT/RNTupleImporter.hxx"
#include "ROOT/RNTupleExporter.hxx"
#include "ROOT/RNTupleInspector.hxx"

#undef  _BACKWARD_BACKWARD_WARNING_H
)DICTPAYLOAD";
    static const char* classesHeaders[] = {
nullptr
};
    static bool isInitialized = false;
    if (!isInitialized) {
      TROOT::RegisterModule("libROOTNTupleUtil",
        headers, includePaths, payloadCode, fwdDeclCode,
        TriggerDictionaryInitialization_libROOTNTupleUtil_Impl, {}, classesHeaders, /*hasCxxModule*/false);
      isInitialized = true;
    }
  }
  static struct DictInit {
    DictInit() {
      TriggerDictionaryInitialization_libROOTNTupleUtil_Impl();
    }
  } __TheDictionaryInitializer;
}
void TriggerDictionaryInitialization_libROOTNTupleUtil() {
  TriggerDictionaryInitialization_libROOTNTupleUtil_Impl();
}

==> root-debug-6.38.00-1-x86_64.pkg.tar.zst: usr/src/debug/root/build-cuda/tree/ntupleutil/G__ROOTNTupleUtil.cxx <==
// Do NOT change. Changes will be lost next time file is generated

#define R__DICTIONARY_FILENAME G__ROOTNTupleUtil
#define R__NO_DEPRECATION

/*******************************************************************/
#include <cstddef>
#include <cstdio>
#include <cstdlib>
#include <cstring>
#include <cassert>
#define G__DICTIONARY
#include "ROOT/RConfig.hxx"
#include "TClass.h"
#include "TDictAttributeMap.h"
#include "TInterpreter.h"
#include "TROOT.h"
#include "TBuffer.h"
#include "TMemberInspector.h"
#include "TInterpreter.h"
#include "TVirtualMutex.h"
#include "TError.h"

#ifndef G__ROOT
#define G__ROOT
#endif

#include "RtypesImp.h"
#include "TIsAProxy.h"
#include "TFileMergeInfo.h"
#include <algorithm>
#include "TCollectionProxyInfo.h"
/*******************************************************************/

#include "TDataMember.h"

// Header files passed as explicit arguments
#include "ROOT/RNTupleImporter.hxx"
#include "ROOT/RNTupleExporter.hxx"
#include "ROOT/RNTupleInspector.hxx"

// Header files passed via #pragma extra_include

// The generated code does not explicitly qualify STL entities
namespace std {} using namespace std;

namespace ROOT {
   // Registration Schema evolution read functions
   int RecordReadRules_libROOTNTupleUtil() {
      return 0;
   }
   static int _R__UNIQUE_DICT_(ReadRules_libROOTNTupleUtil) = RecordReadRules_libROOTNTupleUtil();R__UseDummy(_R__UNIQUE_DICT_(ReadRules_libROOTNTupleUtil));
} // namespace ROOT
namespace {
  void TriggerDictionaryInitialization_libROOTNTupleUtil_Impl() {
    static const char* headers[] = {
"ROOT/RNTupleImporter.hxx",
"ROOT/RNTupleExporter.hxx",
"ROOT/RNTupleInspector.hxx",
nullptr
    };
    static const char* includePaths[] = {
"/build/root/src/build-cuda/include",
"/usr/include",
"/build/root/src/build-cuda/include/",
nullptr
    };
    static const char* fwdDeclCode = R"DICTFWDDCLS(
#line 1 "libROOTNTupleUtil dictionary forward declarations' payload"

#pragma diagnostic push
#pragma clang diagnostic ignored "-Wkeyword-compat"
#pragma clang diagnostic ignored "-Wignored-attributes"
#pragma clang diagnostic ignored "-Wreturn-type-c-linkage"
extern int __Cling_AutoLoading_Map;
#pragma diagnostic pop
)DICTFWDDCLS";
    static const char* payloadCode = R"DICTPAYLOAD(
#line 1 "libROOTNTupleUtil dictionary payload"

#ifndef ROOT_SUPPORT_CLAD
  #define ROOT_SUPPORT_CLAD 1
#endif
#ifndef R__DUMMY_CXX_STANDARD_17
  #define R__DUMMY_CXX_STANDARD_17 1
#endif

#define _BACKWARD_BACKWARD_WARNING_H
// Inline headers
#include "ROOT/RNTupleImporter.hxx"
#include "ROOT/RNTupleExporter.hxx"
#include "ROOT/RNTupleInspector.hxx"

#undef  _BACKWARD_BACKWARD_WARNING_H
)DICTPAYLOAD";
    static const char* classesHeaders[] = {
nullptr
};
    static bool isInitialized = false;
    if (!isInitialized) {
      TROOT::RegisterModule("libROOTNTupleUtil",
        headers, includePaths, payloadCode, fwdDeclCode,
        TriggerDictionaryInitialization_libROOTNTupleUtil_Impl, {}, classesHeaders, /*hasCxxModule*/false);
      isInitialized = true;
    }
  }
  static struct DictInit {
    DictInit() {
      TriggerDictionaryInitialization_libROOTNTupleUtil_Impl();
    }
  } __TheDictionaryInitializer;
}
void TriggerDictionaryInitialization_libROOTNTupleUtil() {
  TriggerDictionaryInitialization_libROOTNTupleUtil_Impl();
}
